# Changelog.jl

Changelog.jl is a Julia package for managing changelogs.

## Installation

Install using Julias package manager:
```julia
pkg> add Changelog
```

## Documentation

The core idea of this package is to make it convenient to write changelog entries with
references to pull requests/issues and let Changelog.jl generate the full URLs.

The typical workflow is as follows:
1. Write a changelog entry in the changelog file (e.g. `CHANGELOG.md`):
   ```
   - Description of new feature with reference to pull request ([#123]).
   ```
2. Run the command
   ```julia
   Changelog.generate(
       Changelog.CommonMark(),          # output type
       "CHANGELOG.md";                  # input and output file
       repo = "JuliaDocs/Changelog.jl", # default repository for links
   )
   ```
   This scans the input for link tokens, generates the full URLs, and inserts a link list at
   the bottom. A tip is to add the command above as a Makefile target. The output would be
   ```
   - Description of new feature with reference to pull request ([#123]).

   <!-- Links generated by Changelog.jl -->
   [#123]: https://github.com/JuliaDocs/Changelog.jl/issues/123
   ```
3. Commit the result.
4. Run the following command to integrate the changelog into documentation built with
   [Documenter](https://github.com/JuliaDocs/Documenter.jl):
   ```julia
   # In docs/make.jl, before makedocs(...)
   Changelog.generate(
       Changelog.Documenter(),                 # output type
       joinpath(@__DIR__, "../CHANGELOG.md"),  # input file
       joinpath(@__DIR__, "src/CHANGELOG.md"); # output file
       repo = "JuliaDocs/Changelog.jl",        # default repository for links
   )
   ```
   The output in would be
   ```
   - Description of new feature with reference to pull request
     ([#123](https://github.com/JuliaDocs/Changelog.jl/issues/123)).
   ```
